@@ -5,6 +5,7 @@ import secrets
 import stat
 from gettext import gettext as _
 from pathlib import Path
+from typing import Callable, Generic, TypeVar
 
 from Cryptodome.Cipher import AES
 from Cryptodome.Random import get_random_bytes
@@ -86,3 +87,21 @@ class KeyFileFilter:
         self.file_filter.add_mime_type("application/x-keepass2")
         self.file_filter.add_mime_type("text/plain")
         self.file_filter.add_mime_type("application/x-iwork-keynote-sffkey")
+
+
+T = TypeVar("T")
+
+
+class LazyValue(Generic[T]):
+    """A lazy value, i.e. a value which is only computed when it is actually needed."""
+
+    def __init__(self, compute: Callable[[], T]):
+        self._value: T | None = None
+        self._compute = compute
+
+    @property
+    def value(self) -> T:
+        """Get the value (and compute it if not done yet)."""
+        if self._value is None:
+            self._value = self._compute()
+        return self._value
